#
# spec file for package python-futures
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define skip_python3 1
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-futures
Version:        3.2.0
Release:        4.1
Summary:        Backport of the concurrent.futures package from Python 3.2
License:        Python-2.0
Group:          Development/Languages/Python
Url:            https://github.com/agronholm/pythonfutures
Source:         https://files.pythonhosted.org/packages/source/f/futures/futures-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
# This packages contain module test from stdlib, nothing to with
# BuildArch field
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if 0%{?rhel} || 0%{?fedora}
BuildRequires:  python-test
%endif
BuildRequires:  python2-devel
BuildArch:      noarch
%python_subpackages

%description
A Java-style futures package for Python

This package is described in PEP-3148 and is included in Python 3.2.

See the Python documentation for a full description.

%prep
%setup -q -n futures-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_exec test_futures.py

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/concurrent/
%{python_sitelib}/futures-%{version}-py*.egg-info

%changelog
* Tue Jan  8 2019 jbrownell@suse.com
- Add dependency on python-test for Red Hat platforms to avoid build
  error "ImportError: No module named _testcapi"
* Thu Dec  6 2018 tchvatal@suse.com
- Fix fdupes call
- Fix homepage
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Sat Dec  9 2017 arun@gmx.de
- specfile:
  * removed CHANGES from %%doc (not in tar-ball anymore), added README.rst
- update to version 3.2.0:
  * The ThreadPoolExecutor class constructor now accepts an optional
    thread_name_prefix argument to make it possible to customize the
    names of the threads created by the pool. Upstream contribution by
    Gregory P. Smith in https://bugs.python.org/issue27664.
  * Backported fixes from upstream (thanks Lisandro Dalcin):
    + python/cpython#1560
    + python/cpython#3270
    + python/cpython#3830
* Tue Nov 14 2017 mpluskal@suse.com
- Skip building oh python3 subpackage as it is not supported
* Thu Jun  1 2017 dmueller@suse.com
- update to 3.1.1:
- Backported sanity checks for the ``max_workers`` constructor argument for ThreadPoolExecutor and
  ProcessPoolExecutor
- Set the default value of ``max_workers`` in ThreadPoolExecutor to ``None``, as in upstream code
  (computes the thread pool size based on the number of CPUs)
- Added support for old-style exception objects
- Switched to the PSF license
* Mon Mar 13 2017 carlos@techbyte.ca
- Update %%python_module redefinition, fixing %%fdupes call
* Fri Mar 10 2017 carlos@techbyte.ca
- Update to singlespec.
* Tue Nov 15 2016 dmueller@suse.com
- update to 3.0.5:
  - Fixed OverflowError with ProcessPoolExecutor on Windows (regression introduced in 3.0.4)
  - Fixed inability to forcibly terminate the process if there are pending workers
  - Fixed AttributeErrors on exit on Python 2.x
  - remove upstreamed fix-testsuite.patch
* Mon Sep 14 2015 ms@suse.com
- Package required in SLE12 due to fate#319400
* Wed Jun  3 2015 mcihar@suse.cz
- Disable tests for SLE 11, the testsuite uses Python 2.7 constructs
* Tue May 19 2015 mcihar@suse.cz
- Enable and fix test suite (fix-testsuite.patch)
* Tue May 19 2015 mcihar@suse.cz
- Update to 3.0.2:
  * Made multiprocessing optional again on implementations other than just Jython
* Tue May  5 2015 benoit.monin@gmx.fr
- update to version 3.0.1:
  * Made Executor.map() non-greedy
- additional changes from version 3.0.0:
  * Dropped Python 2.5 and 3.1 support
  * Removed the deprecated "futures" top level package
  * Applied patch for issue 11777 (Executor.map does not submit
    futures until iter.next() is called)
  * Applied patch for issue 15015 (accessing an non-existing
    attribute)
  * Applied patch for issue 16284 (memory leak)
  * Applied patch for issue 20367 (behavior of
    concurrent.futures.as_completed() for duplicate arguments)
- remove CFLAGS: this is a python only module
- remove futures from package files: not provided anymore
* Fri Feb 27 2015 tbechtold@suse.com
- update to version 2.2.0:
  - Added the set_exception_info() and exception_info() methods to Future
    to enable extraction of tracebacks on Python 2.x
  - Added support for Future.set_exception_info() to ThreadPoolExecutor
* Mon Mar 24 2014 toddrme2178@gmail.com
- Updated to 2.1.6
  - Fixed a problem with files missing from the source distribution
- Updated to 2.1.5
  - Fixed Jython compatibility
  - Added metadata for wheel support
- Updated to 2.1.4
  - Ported the library again from Python 3.2.5 to get the latest bug fixes
* Wed Apr 24 2013 cfarrell@suse.com
- license update: BSD-2-Clause
  See LICENSE file
* Tue Apr  9 2013 speilicke@suse.com
- Initial version
